==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/ca/lang.php <==
<?php
/**
 * Catalan language file
 *
 * @author Carles Bellver <carles.bellver@gmail.com>
 * @author carles.bellver@gmail.com
 * @author carles.bellver@cent.uji.es
 * @author Carles Bellver <carles.bellver@cent.uji.es>
 */
$lang['menu']                  = 'Gestió d\'usuaris';
$lang['noauth']                = '(l\'autenticació d\'usuaris no està disponible)';
$lang['nosupport']             = '(la gestió d\'usuaris no funciona)';
$lang['badauth']               = 'el mecanisme d\'autenticació no és vàlid';
$lang['user_id']               = 'Usuari';
$lang['user_pass']             = 'Contrasenya';
$lang['user_name']             = 'Nom real';
$lang['user_mail']             = 'Correu electrònic';
$lang['user_groups']           = 'Grups';
$lang['field']                 = 'Camp';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Afegeix';
$lang['delete']                = 'Suprimeix';
$lang['delete_selected']       = 'Suprimeix els seleccionats';
$lang['edit']                  = 'Edita';
$lang['edit_prompt']           = 'Edita aquest usuari';
$lang['modify']                = 'Desa els canvis';
$lang['search']                = 'Cerca';
$lang['search_prompt']         = 'Fes la cerca';
$lang['clear']                 = 'Reinicia el filtre de cerca';
$lang['filter']                = 'Filtre';
$lang['summary']               = 'Visualització d\'usuaris %1$d-%2$d de %3$d trobats. %4$d usuaris en total.';
$lang['nonefound']             = 'No s\'han trobat usuaris. %d usuaris en total.';
$lang['delete_ok']             = 'S\'han suprimit %d usuaris';
$lang['delete_fail']           = 'No s\'han pogut suprimir %d.';
$lang['update_ok']             = 'L\'usuari ha estat actualitzat amb èxit';
$lang['update_fail']           = 'Ha fallat l\'actualització de l\'usuari';
$lang['update_exists']         = 'No s\'ha pogut canviar el nom de l\'usuari. El nom d\'usuari especificat (%s) ja existeix (qualsevol altre canvi sí que serà efectiu).';
$lang['start']                 = 'inici';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'següent';
$lang['last']                  = 'final';
$lang['edit_usermissing']      = 'L\'usuari seleccionat no s\'ha pogut trobar. Potser el nom d\'usuari especificat s\'ha suprimit o modificat des d\'un altre lloc.';
$lang['user_notify']           = 'Notificació a l\'usuari';
$lang['note_notify']           = 'Els correus de notificació només s\'envien si es canvia la contrasenya de l\'usuari.';
$lang['note_group']            = 'Els nous usuaris s\'afegeixen al grup per defecte (%s) si no s\'especifica un altre grup.';
$lang['add_ok']                = 'L\'usuari s\'ha afegit amb èxit';
$lang['add_fail']              = 'No s\'ha pogut afegir l\'usuari';
$lang['notify_ok']             = 'S\'ha enviat el correu de notificació';
$lang['notify_fail']           = 'No s\'ha pogut enviar el correu de notificació';

==> dokuwiki_0.0.20160626.a.orig.tar.gz: dokuwiki-2016-06-26a/lib/plugins/usermanager/lang/ca/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Carles Bellver <carles.bellver@gmail.com>
 * @author carles.bellver@gmail.com
 * @author carles.bellver@cent.uji.es
 * @author Carles Bellver <carles.bellver@cent.uji.es>
 * @author daniel@6temes.cat
 */
$lang['menu']                  = 'Gestió d\'usuaris';
$lang['noauth']                = '(l\'autenticació d\'usuaris no està disponible)';
$lang['nosupport']             = '(la gestió d\'usuaris no funciona)';
$lang['badauth']               = 'el mecanisme d\'autenticació no és vàlid';
$lang['user_id']               = 'Usuari';
$lang['user_pass']             = 'Contrasenya';
$lang['user_name']             = 'Nom real';
$lang['user_mail']             = 'Correu electrònic';
$lang['user_groups']           = 'Grups';
$lang['field']                 = 'Camp';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Afegeix';
$lang['delete']                = 'Suprimeix';
$lang['delete_selected']       = 'Suprimeix els seleccionats';
$lang['edit']                  = 'Edita';
$lang['edit_prompt']           = 'Edita aquest usuari';
$lang['modify']                = 'Desa els canvis';
$lang['search']                = 'Cerca';
$lang['search_prompt']         = 'Fes la cerca';
$lang['clear']                 = 'Reinicia el filtre de cerca';
$lang['filter']                = 'Filtre';
$lang['summary']               = 'Visualització d\'usuaris %1$d-%2$d de %3$d trobats. %4$d usuaris en total.';
$lang['nonefound']             = 'No s\'han trobat usuaris. %d usuaris en total.';
$lang['delete_ok']             = 'S\'han suprimit %d usuaris';
$lang['delete_fail']           = 'No s\'han pogut suprimir %d.';
$lang['update_ok']             = 'L\'usuari ha estat actualitzat amb èxit';
$lang['update_fail']           = 'Ha fallat l\'actualització de l\'usuari';
$lang['update_exists']         = 'No s\'ha pogut canviar el nom de l\'usuari. El nom d\'usuari especificat (%s) ja existeix (qualsevol altre canvi sí que serà efectiu).';
$lang['start']                 = 'inici';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'següent';
$lang['last']                  = 'final';
$lang['edit_usermissing']      = 'L\'usuari seleccionat no s\'ha pogut trobar. Potser el nom d\'usuari especificat s\'ha suprimit o modificat des d\'un altre lloc.';
$lang['user_notify']           = 'Notificació a l\'usuari';
$lang['note_notify']           = 'Els correus de notificació només s\'envien si es canvia la contrasenya de l\'usuari.';
$lang['note_group']            = 'Els nous usuaris s\'afegeixen al grup per defecte (%s) si no s\'especifica un altre grup.';
$lang['note_pass']             = 'La contrasenya es generarà automàticament si el camp es deixa en blanc i les notificacions estan habilitades per a aquest usuari.';
$lang['add_ok']                = 'L\'usuari s\'ha afegit amb èxit';
$lang['add_fail']              = 'No s\'ha pogut afegir l\'usuari';
$lang['notify_ok']             = 'S\'ha enviat el correu de notificació';
$lang['notify_fail']           = 'No s\'ha pogut enviar el correu de notificació';
